==> libchipcard2_1.9.14.99+1.9.15beta.orig.tar.gz: libchipcard2-1.9.15beta/src/lib/version.h <==
/***************************************************************************
 $RCSfile: version.h.in,v $
                             -------------------
    cvs         : $Id: version.h.in,v 1.1 2005/01/24 23:51:51 aquamaniac Exp $
    begin       : Tue Dec 23 2003
    copyright   : (C) 2003 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef CHIPCARD2_VERSION_H
#define CHIPCARD2_VERSION_H

#define CHIPCARD_VERSION_MAJOR 1
#define CHIPCARD_VERSION_MINOR 9
#define CHIPCARD_VERSION_PATCHLEVEL 15
#define CHIPCARD_VERSION_BUILD 0
#define CHIPCARD_VERSION_TAG "beta"
#define CHIPCARD_VERSION_FULL_STRING "1.9.15.0beta"
#define CHIPCARD_VERSION_STRING "1.9.15beta"


#endif /* CHIPCARD2_VERSION_H */

==> libchipcard_5.0.3beta.orig.tar.gz: libchipcard-5.0.3beta/src/lib/version.h <==
/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id$
    begin       : Tue Dec 23 2003
    copyright   : (C) 2003 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef CHIPCARD2_VERSION_H
#define CHIPCARD2_VERSION_H

#define CHIPCARD_VERSION_MAJOR 5
#define CHIPCARD_VERSION_MINOR 0
#define CHIPCARD_VERSION_PATCHLEVEL 3
#define CHIPCARD_VERSION_BUILD 0
#define CHIPCARD_VERSION_TAG "beta"
#define CHIPCARD_VERSION_FULL_STRING "5.0.3.0beta"
#define CHIPCARD_VERSION_STRING "5.0.3"


#endif /* CHIPCARD2_VERSION_H */
